@@ -1,10 +1,12 @@
 
 """Python language extensions"""
 
+from __builtin__ import min as minimum, max as maximum
 from application.python.types import NullType
+from collections import deque
 
 
-__all__ = ['Null', 'limit']
+__all__ = 'Null', 'limit', 'subclasses'
 
 
 Null = NullType()
@@ -17,8 +19,16 @@ except ValueError:
     positive_infinite = 1e300000
 
 
+# noinspection PyShadowingBuiltins
 def limit(value, min=negative_infinite, max=positive_infinite):
     """Limit a numeric value to the specified range"""
-    from __builtin__ import min as minimum, max as maximum
     return maximum(min, minimum(value, max))
 
+
+def subclasses(cls):
+    """Recursively find all the subclasses of a given class"""
+    classes = deque(cls.__subclasses__())
+    while classes:
+        subclass = classes.popleft()
+        classes.extend(subclass.__subclasses__())
+        yield subclass
